@@ -10,7 +10,7 @@ play_initials_bank = ['en-GB', 'af', 'am', 'ar', 'hy-AM', 'az-AZ', 'bn-BD', 'eu-
 # the actual conversion of a text
 def translate_sentence(translate_client, project_id, language_src, language_dest, text):
     # translate
-    parent = translate_client.location_path(project_id, "global")
+    parent = f'projects/{project_id}'
     try:
         response = translate_client.translate_text(
             parent=parent,
